@@ -2,9 +2,9 @@
 
 import traceback
 
-from gv_services.proto.archivist_pb2 import TrafficData
+from gv_services.proto.archivist_pb2 import DataQuality, TrafficData
 from gv_services.storage import filestorage
-from gv_utils import datetime, enums, geometry
+from gv_utils import datetime, enums, geometry, protobuf
 from gv_utils.csv import ENCODING
 
 METROPME = enums.DataTypeId.metropme
@@ -79,3 +79,13 @@ class Archivist:
             self.logger.error('An error occurred while getting {} data between {} and {}.'
                               .format(datatype, datetime.to_string(fromdate), datetime.to_string(todate)))
             yield TrafficData(trafficdata=b'', applyto='all')
+
+    async def get_data_quality(self, request):
+        datatype = request.datatype
+        dataquality = b''
+        try:
+            dataquality = await self.dbstorage.get_data_quality(datatype)
+        except:
+            self.logger.error(traceback.format_exc())
+            self.logger.error('An error occurred while getting {} data quality.'.format(datatype))
+        return await protobuf.encode_data_quality(dataquality)
