@@ -58,6 +58,10 @@ class Interface(InterfaceBase):
         async for response in self.archivist.get_data(await stream.recv_message()):
             await stream.send_message(response)
 
+    async def get_data_quality(self, stream):
+        response = await self.archivist.get_data_quality(await stream.recv_message())
+        await stream.send_message(response)
+
     async def add_mapping_roads_data_points(self, stream):
         success = await self.geographer.add_mapping_roads_data_points(await stream.recv_message())
         await stream.send_message(Ack(success=success))
