@@ -122,12 +122,12 @@ async def select_roads_ids(dbpool, eids=None, area=None):
 
 
 async def select_roads(dbpool, eids=None, area=None, hasmapping=False):
-    query = 'SELECT jsonb_object_agg(eid, json_build_object(\'id\', id, \'eid\', eid, \'geom\', ST_AsText(geom), ' \
+    query = 'SELECT jsonb_object_agg(eid, json_build_object(\'id\', road.id, \'eid\', eid, \'geom\', ST_AsText(geom), ' \
             '\'webatt\', web_att, \'att\', att)) AS res ' \
             'FROM road'
 
     if hasmapping:
-        query += 'INNER JOIN road_data_point ON road_data_point.road = road.id '
+        query += ' INNER JOIN road_data_point ON road_data_point.road = road.id '
 
     whereclause = ''
     whereparams = ()
@@ -199,6 +199,25 @@ async def select_roads_indicators_eids(dbpool, fromdate, todate, area=None):
     return (await _run_fetch_request(dbpool, query, whereparams, codecs=('geometry',)))[0]['res']
 
 
+async def select_data_points_data_quality(dbpool, datatypeid):
+    query = 'SELECT jsonb_object_agg(trim(both \'"\' from to_json(dpdq.day)::text), dpdq.data_quality) AS res ' \
+            'FROM data_point_data_quality AS dpdq '
+    whereclause = ''
+    whereparams = ()
+    if datatypeid is not None:
+        whereclause, whereparams = _add_where_condition('WHERE ', whereparams,
+                                                        _build_where_clause_for_eids_fields,
+                                                        (datatypeid, 'dpdq.data_type'))
+    query += whereclause + ';'
+    return (await _run_fetch_request(dbpool, query, whereparams))[0]['res']
+
+
+async def select_roads_data_quality(dbpool):
+    query = 'SELECT jsonb_object_agg(trim(both \'"\' from to_json(rdq.day)::text), rdq.data_quality) AS res ' \
+            'FROM road_data_quality AS rdq;'
+    return (await _run_fetch_request(dbpool, query, ()))[0]['res']
+
+
 def _add_where_condition(whereclause, whereparams, build_func, funcparams, paramindex=None):
     if paramindex is None:
         paramindex = len(whereparams) + 1
