@@ -143,6 +143,15 @@ class DbStorage:
 
         return trafficieids
 
+    async def get_data_quality(self, datatypeeid):
+        result = {}
+        if datatypeeid == METROPMEDATATYPE or datatypeeid == TOMTOMFCDDATATYPE:
+            if datatypeeid in self.datatypeseidtoid:
+                result = await dbrequest.select_data_points_data_quality(self.dbpool, self.datatypeseidtoid[datatypeeid])
+        elif datatypeeid == ROADSDATATYPE:
+            result = await dbrequest.select_roads_data_quality(self.dbpool)
+        return result
+
     async def _init_cache(self):
         self.datatypeseidtoid = {}
         self.datapointseidtoid = {}
