@@ -5,7 +5,7 @@ import bz2
 from concurrent.futures import ProcessPoolExecutor
 from datetime import timedelta
 
-from gv_utils import datetime, filesystem
+from gv_utils import csv, datetime, filesystem
 
 
 DATA_FILE_STRUCT = '%H-%M.csv.bz2'
@@ -38,4 +38,6 @@ async def get_data(datatype, fromdate, todate, basepath, freq=1, window=0):
                 mul *= -1
             else:
                 break
+        if data == b'':
+            data = str(int(datadate.timestamp())).encode(csv.ENCODING)
         yield data
